@@ -5,7 +5,6 @@ from django.db import models
 from pulpcore.plugin.models import (
     Content,
     Distribution,
-    FilesystemExporter,
     Publication,
     Remote,
     Repository,
@@ -79,18 +78,11 @@ class FileRepository(Repository):
         from pulp_file.app import tasks
 
         if self.autopublish:
-            publication = tasks.publish(
+            tasks.publish(
                 manifest=self.manifest,
                 repository_version_pk=version.pk,
             )
 
-            distributions = self.distributions.all()
-
-            if publication and distributions:
-                for distribution in distributions:
-                    distribution.publication = publication
-                    distribution.save()
-
     def finalize_new_version(self, new_version):
         """
         Finalize and validate the new repository version.
@@ -135,14 +127,3 @@ class FileDistribution(Distribution):
 
     class Meta:
         default_related_name = "%(app_label)s_%(model_name)s"
-
-
-class FileFilesystemExporter(FilesystemExporter):
-    """
-    File system exporter for 'file' content.
-    """
-
-    TYPE = "filesystem"
-
-    class Meta:
-        default_related_name = "%(app_label)s_%(model_name)s"
